Index: /trunk/gli/src/org/greenstone/gatherer/shell/GBuildProgressMonitor.java
===================================================================
--- /trunk/gli/src/org/greenstone/gatherer/shell/GBuildProgressMonitor.java	(revision 11075)
+++ /trunk/gli/src/org/greenstone/gatherer/shell/GBuildProgressMonitor.java	(revision 11076)
@@ -39,5 +39,4 @@
 import java.awt.Component;
 import java.util.ArrayList;
-import javax.swing.JProgressBar;
 import org.greenstone.gatherer.Configuration;
 import org.greenstone.gatherer.DebugStream;
@@ -45,4 +44,5 @@
 import org.greenstone.gatherer.Gatherer;
 import org.greenstone.gatherer.cdm.CollectionDesignManager;
+import org.greenstone.gatherer.gui.GProgressBar;
 import org.greenstone.gatherer.util.StaticStrings;
 /** This implementation of <i>GShellProgressMonitor</i> is designed to parse and translate the progress of a buildcol.pl call.
@@ -126,12 +126,12 @@
     private int state = BASE;
     /** The progress bar this monitor updates. */
-    private JProgressBar progress_bar;
+    private GProgressBar progress_bar;
     /** A progress bar that is shared between this this listener and the Import monitor. */
-    private JProgressBar shared_progress_bar;
+    private GProgressBar shared_progress_bar;
 
     /** Construct a new GBuildProgressMonitor. */
-    public GBuildProgressMonitor(JProgressBar shared_progress_bar) {
+    public GBuildProgressMonitor(GProgressBar shared_progress_bar) {
 	this.shared_progress_bar = shared_progress_bar;
-	progress_bar = new JProgressBar();
+	progress_bar = new GProgressBar();
 	progress_bar.setMaximum(MAX);
 	progress_bar.setMinimum(MIN);
@@ -142,7 +142,7 @@
 
     /** Method to register a new progress bar with this monitor.
-     * @param progress_bar The new <strong>JProgressBar</strong>.
+     * @param progress_bar The new <strong>GProgressBar</strong>.
      */	 
-    public void addProgressBar(JProgressBar progress_bar) {
+    public void addProgressBar(GProgressBar progress_bar) {
 	this.progress_bar = progress_bar;
 	progress_bar.setMaximum(MAX);
@@ -162,5 +162,5 @@
 	return 1;
     }
     /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>JProgressBar</strong> but there may be others implemented later.
      * @return A <strong>Component</strong> on which the progress of the process is being displayed.
      */
@@ -169,5 +169,5 @@
     }
 
-    public JProgressBar getSharedProgress() {
+    public GProgressBar getSharedProgress() {
 	return shared_progress_bar;
     }
@@ -533,5 +533,5 @@
     }
 
-    public void setSharedProgressBar(JProgressBar shared_progress_bar) {
+    public void setSharedProgressBar(GProgressBar shared_progress_bar) {
 	this.shared_progress_bar = shared_progress_bar;
     }
@@ -162,5 +162,5 @@
 	return 1;
     }
-    /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>JProgressBar</strong> but there may be others implemented later.
+    /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>GProgressBar</strong> but there may be others implemented later.
      * @return A <strong>Component</strong> on which the progress of the process is being displayed.
      */
Index: /trunk/gli/src/org/greenstone/gatherer/shell/GImportProgressMonitor.java
===================================================================
--- /trunk/gli/src/org/greenstone/gatherer/shell/GImportProgressMonitor.java	(revision 11075)
+++ /trunk/gli/src/org/greenstone/gatherer/shell/GImportProgressMonitor.java	(revision 11076)
@@ -39,9 +39,9 @@
 import java.awt.Component;
 import java.util.*;
-import javax.swing.JProgressBar;
 import org.greenstone.gatherer.Configuration;
 import org.greenstone.gatherer.DebugStream;
 import org.greenstone.gatherer.Dictionary;
 import org.greenstone.gatherer.Gatherer;
+import org.greenstone.gatherer.gui.GProgressBar;
 import org.greenstone.gatherer.util.StaticStrings;
 
@@ -69,8 +69,8 @@
     private int threshold = Configuration.SYSTEMS_MODE;
     /** The progress bar this monitor updates. */
-    private JProgressBar progress_bar;
+    private GProgressBar progress_bar;
 
     /** The progress bar that is shared with build monitor. */
-    private JProgressBar shared_progress_bar;
+    private GProgressBar shared_progress_bar;
 
     /** */
@@ -116,5 +116,5 @@
 
     public GImportProgressMonitor() {
-	progress_bar = new JProgressBar();
+	progress_bar = new GProgressBar();
 	progress_bar.setIndeterminate(false);
 	progress_bar.setMaximum(MAXIMUM);
@@ -123,5 +123,5 @@
 	progress_bar.setStringPainted(true);
 	next_progress_value = CALCULATION;
-	shared_progress_bar = new JProgressBar();
+	shared_progress_bar = new GProgressBar();
 	shared_progress_bar.setIndeterminate(false);
 	shared_progress_bar.setMaximum(MAXIMUM * 2);
@@ -133,7 +133,7 @@
 
     /** Method to register a new progress bar with this monitor.
-     * @param progress_bar The new <strong>JProgressBar</strong>.
-     */
-    public void addProgressBar(JProgressBar progress_bar) {
+     * @param progress_bar The new <strong>GProgressBar</strong>.
+     */
+    public void addProgressBar(GProgressBar progress_bar) {
 	this.progress_bar = progress_bar;
 	progress_bar.setMaximum(MAXIMUM);
@@ -160,5 +160,5 @@
     }
 
     /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>JProgressBar</strong> but there may be others implemented later.
      * @return A <strong>Component</strong> on which the progress of the process is being displayed.
      */
@@ -167,5 +167,5 @@
     }
 
-    public JProgressBar getSharedProgress() {
+    public GProgressBar getSharedProgress() {
 	return shared_progress_bar;
     }
@@ -160,5 +160,5 @@
     }
 
-    /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>JProgressBar</strong> but there may be others implemented later.
+    /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>GProgressBar</strong> but there may be others implemented later.
      * @return A <strong>Component</strong> on which the progress of the process is being displayed.
      */
Index: /trunk/gli/src/org/greenstone/gatherer/shell/GShellProgressMonitor.java
===================================================================
--- /trunk/gli/src/org/greenstone/gatherer/shell/GShellProgressMonitor.java	(revision 11075)
+++ /trunk/gli/src/org/greenstone/gatherer/shell/GShellProgressMonitor.java	(revision 11076)
@@ -50,5 +50,5 @@
 import java.awt.Component;
 import java.util.ArrayList;
-import javax.swing.JProgressBar;
+import org.greenstone.gatherer.gui.GProgressBar;
 
 /** When implemented, this interface allows another class to monitor the progress of a <strong>GShell</strong> process. Specifically implementing classes should be designed to take the textual output from the process and then translate that message into some quanitive measure of progress which can then be shown on the progress bar.
@@ -56,7 +56,7 @@
 public interface GShellProgressMonitor {
     /** Method to register a new progress bar with this monitor.
-     * @param progress_bar The new <strong>JProgressBar</strong>.
+     * @param progress_bar The new <strong>GProgressBar</strong>.
      */
-    public void addProgressBar(JProgressBar progress_bar);
+    public void addProgressBar(GProgressBar progress_bar);
 
     /** Determine the script exit value according to the progress monitor. This gets around a problem where several script failures actually result with a successful exit value.
@@ -65,7 +65,7 @@
     public int exitValue();
 
-    public JProgressBar getSharedProgress();
+    public GProgressBar getSharedProgress();
 
     /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>JProgressBar</strong> but there may be others implemented later.
      * @return A <strong>Component</strong> on which the progress of the process is being displayed.
      */
@@ -65,7 +65,7 @@
 
-    /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>JProgressBar</strong> but there may be others implemented later.
+    /** Method to retrieve whatever control is being used as the progress indicator. Usually a <strong>GProgressBar</strong> but there may be others implemented later.
      * @return A <strong>Component</strong> on which the progress of the process is being displayed.
      */
